==> ejc-assistrmat-impl-3.0.0-20220322.083356-4-sources.jar: com/ejianc/business/assist/rmat/bean/RecordClauseEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 周转材租赁合同-合同条款记录表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistrmat_contract_record_clause")
public class RecordClauseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="record_id")
    private Long recordId; // 记录表id
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value="source_bid")
    private Long sourceBid; // 来源合同子表id
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="change_bid")
    private Long changeBid; // 变更子表主键
    @TableField(value="clause_name_id")
    private Long clauseNameId; // 合同条款名称Id
    @TableField(value="clause_name")
    private String clauseName; // 合同条款名称
    @TableField(value="clause_content")
    private String clauseContent; // 合同条款内容
    
    
    

    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceBid() {
        return sourceBid;
    }

    public void setSourceBid(Long sourceBid) {
        this.sourceBid = sourceBid;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
    public Long getClauseNameId() {
        return clauseNameId;
    }

    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }
    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }
    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }
    
}

==> ejc-assistrmat-impl-3.0.0-20240125.094748-396-sources.jar: com/ejianc/business/assist/rmat/bean/RecordClauseEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 周转材租赁合同-合同条款记录表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistrmat_contract_record_clause")
public class RecordClauseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="record_id")
    private Long recordId; // 记录表id
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value="source_bid")
    private Long sourceBid; // 来源合同子表id
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="change_bid")
    private Long changeBid; // 变更子表主键
    @TableField(value="clause_name_id")
    private Long clauseNameId; // 合同条款名称Id
    @TableField(value="clause_name")
    private String clauseName; // 合同条款名称
    @TableField(value="clause_content")
    private String clauseContent; // 合同条款内容
    @TableField(value="necessary_status")
    private Integer necessaryStatus; // 是否必填：0-否，1-是
    
    

    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceBid() {
        return sourceBid;
    }

    public void setSourceBid(Long sourceBid) {
        this.sourceBid = sourceBid;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
    public Long getClauseNameId() {
        return clauseNameId;
    }

    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }
    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }
    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }

    public Integer getNecessaryStatus() {
        return necessaryStatus;
    }

    public void setNecessaryStatus(Integer necessaryStatus) {
        this.necessaryStatus = necessaryStatus;
    }
    
}
